#############################
Physical Quantities with Pint
#############################

Additional resources fields that include a unit.

.. note::

    This contrib module depends on the `Pint units library <http://pint.readthedocs.org/>`_ this can be installed with::

        pip install pint

Fields
******

FloatField
==========

``class FloatField([max_length=None, **options])``

A float.

FloatField has one extra argument:
